# CARPHA R-Training <a href='https://www.bsc.es/es'><img src='https://pbs.twimg.com/profile_images/1807760468271894528/In5BEGRl_400x400.jpg' align="right" height="190" width="190" /></a>

<!-- badges: start -->

<!-- [![Lifecycle:
maturing](https://img.shields.io/badge/lifecycle-maturing-blue.svg)](https://lifecycle.r-lib.org/articles/stages.html#maturing)
[![R-CMD-check](https://github.com/epiforecasts/EpiNow2/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/epiforecasts/EpiNow2/actions/workflows/R-CMD-check.yaml)
[![MIT
license](https://img.shields.io/badge/License-MIT-blue.svg)](https://github.com/epiforecasts/EpiNow2/blob/main/LICENSE.md/)
[![GitHub
contributors](https://img.shields.io/github/contributors/epiforecasts/EpiNow2)](https://github.com/epiforecasts/EpiNow2/graphs/contributors)

[![universe](https://epiforecasts.r-universe.dev/badges/EpiNow2)](http://epiforecasts.r-universe.dev/ui/#package:EpiNow2)
[![GitHub
commits](https://img.shields.io/github/commits-since/epiforecasts/EpiNow2/v1.4.0.svg?color=orange)](https://GitHub.com/epiforecasts/EpiNow2/commit/main/)
[![DOI](https://zenodo.org/badge/272995211.svg)](https://zenodo.org/badge/latestdoi/272995211) -->
<!-- badges: end -->
<br>
<br>

## Overview
<p style="font-family: Arial, sans-serif; font-size: 14px;">
  Welcome to the CARPHA R-training repository. This repository was developed in the framwork of the <em>'Early Warning Systems For Climate Sensitive Infectious Diseases Training Workshop'</em> held in Barbados April 22-25 2025. The aim of this repository is to give an introduction on how to automate the data processing in climate & health research using R. Our tools and documentation are designed to facilitate data harmonization, analysis, and reporting for health researchers and practitioners. 
</p>
<p style="font-family: Arial, sans-serif; font-size: 14px;">
  During this course you will learn the following topics:
  <ul>
    <li> How to install R and RStudio </li>
    <li> First steps programming in R </li>
    <li> Cleaning & aggregating health data </li>
    <li> Processing climate data </li>
    <li> Harmonizing and visualising the data</li>
  </ul>
</p>


## Dependencies

<table>
  <tr>
    <td align="center">
      <a href="https://cran.r-project.org/web/packages/dplyr/index.html" target="_blank">
        <img src="https://raw.githubusercontent.com/harmonize-tools/harmonize-tools.github.io/a0813b1974da6943e1211d1ea29b7cbba75dc99a/public/cards/toolkits/data4health.svg" height="50" alt="dplyr logo">
      </a>
    </td>
    <td align="left">
      <strong>data4health</strong><br>
      Provides a set of tools to process health datasets in R.<br>
    </td>
  </tr>
  <tr>
    <td align="center">
      <a href="https://cran.r-project.org/web/packages/ggplot2/index.html" target="_blank">
        <img src="https://raw.githubusercontent.com/harmonize-tools/harmonize-tools.github.io/a0813b1974da6943e1211d1ea29b7cbba75dc99a/public/cards/toolkits/clim4health.svg" height="50" alt="ggplot2 logo">
      </a>
    </td>
    <td align="left">
      <strong>clim4health</strong><br>
      Provides a set of tools to process climate datasets in R.<br>
    </td>
  </tr>
  <tr>
    <td align="center">
      <a href="https://cran.r-project.org/web/packages/ggplot2/index.html" target="_blank">
        <img src="https://imgs.search.brave.com/7xErK1yv_WwEZ-syGmCUbH4n1THQcF7ukwTLS42zAyM/rs:fit:860:0:0/g:ce/aHR0cHM6Ly9yLWdy/YXBoLWdhbGxlcnku/Y29tL2ltZy9vdGhl/ci9nZ3Bsb3QySGV4/LmpwZw" height="50" alt="ggplot2 logo">
      </a>
    </td>
    <td align="left">
      <strong>GHRexplore</strong><br>
      Provides a set of tools to visualise datasets in R.<br>
    </td>
  </tr>
</table>



<!-- ## Installation

You can install the latest version of the package from GitHub using the `remotes` package:

```R
# Install remotes if you haven't already
install.packages("remotes")

# Install the package from GitHub
remotes::install_github("your_username/your_package_name")
``` -->
<!-- 
## Vignette

This document provides a guide to working with NetCDF files in R using the `ncdf4` and `raster` packages. The following example demonstrates how to read a NetCDF file, extract data, and visualize it.

<details>
<summary>
  Vignette
</summary>
   -->
<!-- ## Prerequisites

Before running the script, ensure you have the necessary packages installed. You can install them using the following commands:

```r
install.packages("ncdf4")
install.packages("raster")
install.packages("ggplot2")
```

## R script
```r
# Load necessary libraries
library(ncdf4)
library(raster)
library(ggplot2)

# Set the path to your NetCDF file
nc_file <- "path/to/your/file.nc"

# Open the NetCDF file
nc <- nc_open(nc_file)

# Print the NetCDF file summary
print(nc)

# Extract data from a specific variable (e.g., 'temperature')
# Replace 'temperature' with the actual variable name in your NetCDF file
var_name <- "temperature"
temperature <- ncvar_get(nc, var_name)

# Get the dimensions of the data
lon <- ncvar_get(nc, "lon")
lat <- ncvar_get(nc, "lat")
time <- ncvar_get(nc, "time")

# Close the NetCDF file
nc_close(nc)

# Create a raster layer for the first time step (if applicable)
# Modify the indexing based on your data structure
r <- raster(t(temperature[,,1]), xmn=min(lon), xmx=max(lon), ymn=min(lat), ymx=max(lat), crs=CRS("+proj=longlat +datum=WGS84"))

# Plot the raster layer using base R plot
plot(r, main=paste("Temperature at Time Step 1"))

# Convert the raster to a data frame for ggplot2 visualization
r_df <- as.data.frame(r, xy=TRUE)

# Plot the raster layer using ggplot2
ggplot(r_df, aes(x=x, y=y, fill=layer)) +
  geom_raster() +
  coord_fixed() +
  scale_fill_viridis_c() +
  labs(title="Temperature at Time Step 1", x="Longitude", y="Latitude", fill="Temperature") +
  theme_minimal()
```
</details> -->

## Resources

<details>
<summary>
GHR resume
</summary>
<br>
  
The goal of the [`Global Health Resilience`](https://www.bsc.es/discover-bsc/organisation/research-departments/global-health-resilience) group at the Barcelona Supercomputing Center is to co-design policy-relevant decision-support tools to enhance surveillance, preparedness, and response to global health challenges, with a focus on climate-sensitive infectious diseases. The group applies a transdisciplinary approach, co-developing solutions at the interface of epidemiology, climate science, planetary health, biology, mathematical modelling, and data science.

</details>

<details>
<summary>
R installation
</summary>
<br>
You can find additional tutorials on how to install R:
<ul>
  <li> link 1</li>
  <li> link 2</li>
  <li> link 3</li>
</ul>
<br>
</details>

<details>
<summary>
R programming
</summary>
<br>
You can find additional tutorials on how to get started in R:
<ul>
  <li> link 1</li>
  <li> link 2</li>
  <li> link 3</li>
</ul>
</details>

## Organizations

<table>
  <tr>
    <td align="center">
      <a href="https://www.bsc.es/" target="_blank">
        <img src="https://imgs.search.brave.com/t_FUOTCQZmDh3ddbVSX1LgHYq4mzCxvVA8U_YHywMTc/rs:fit:500:0:0/g:ce/aHR0cHM6Ly9zb21t/YS5lcy93cC1jb250/ZW50L3VwbG9hZHMv/MjAyMi8wNC9CU0Mt/Ymx1ZS1zbWFsbC5q/cGc" height="64" alt="dplyr logo">
      </a>
    </td>
    <td align="left">
      <strong>GHR</strong><br>
      Global Health Resilience
    </td>
  </tr>
</table>

## Contact information
<table style="width: 100%; font-family: Arial, sans-serif; border-collapse: collapse;">
  <tr>
    <td rowspan="4" style="width: 150px; text-align: center; vertical-align: middle;">
      <a href="https://github.com/drrachellowe">
        <img src="https://media.licdn.com/dms/image/D4D03AQEg-32syXikRQ/profile-displayphoto-shrink_800_800/0/1698574612492?e=1726704000&v=beta&t=-qiFVKWw-_K9iwsMWrgrQiGpVas-7kwcOVEIU0oh8fc" width="120" height="120" align="center" />
      </a>
    </td>
    <td style="padding: 5px;">
      <strong style="font-size: 1.2em;">Rachel Lowe</strong> <span style="font-size: 0.9em; color: #555;">(Main researcher)</span>
      <a href="https://orcid.org/0000-0003-3939-7343" style="margin-left: 10px;">
        <img src="https://orcid.org/sites/default/files/images/orcid_16x16.png" alt="ORCID" style="width: 16px; height: 16px;" />
      </a>
    </td>
  </tr>
  <tr>
    <td style="padding: 5px;">
      <b>Organization</b>: Barcelona Supercomputing Center
    </td>
  </tr>
  <tr>
    <td style="padding: 5px;">
      <b>Group</b>: Global Health Resilience
    </td>
  </tr>
  <tr>
    <td style="padding: 5px;">
      <b>Position</b>: Group Leader
      <br>
      <b>Email</b>: <a href="mailto:rachel.lowe@bsc.es" style="color: #1a73e8;">rachel.lowe@bsc.es</a>
    </td>
  </tr>
</table>

## Developers
<table style="width: 100%; font-family: Arial, sans-serif; border-collapse: collapse;">
  <tr>
    <td rowspan="4" style="width: 150px; text-align: center; vertical-align: middle;">
      <a href="https://github.com/RaulCapellanFernandez">
        <img src="https://media.licdn.com/dms/image/C4D03AQG3wdNNRHPqAQ/profile-displayphoto-shrink_400_400/0/1636441830003?e=1726704000&v=beta&t=9gCt_j8gI2z_XPGE0y8L2iVAAcUwdFV39lFtMD5nQUU" width="120" height="120" align="center"/>
      </a>
    </td>
    <td style="padding: 5px;">
      <strong style="font-size: 1em;">Raúl Capellán</strong>
      <a href="https://www.linkedin.com/in/ra%C3%BAl-capell%C3%A1n-14a8b012a/" style="margin-left: 10px;">
        <img src="https://imgs.search.brave.com/SQsaFNKXL9x2pacICOrPpnY5c1-Eee1Vf0jOmntInaM/rs:fit:860:0:0:0/g:ce/aHR0cHM6Ly91cGxv/YWQud2lraW1lZGlh/Lm9yZy93aWtpcGVk/aWEvY29tbW9ucy9j/L2NhL0xpbmtlZElu/X2xvZ29faW5pdGlh/bHMucG5n" alt="LINKEDIN" width="16" height="16" align="center" />
      </a>
    </td>
  </tr>
  <tr>
    <td style="padding: 5px;">
      <b>Organization</b>: Barcelona Supercomputing Center
    </td>
  </tr>
  <tr>
    <td style="padding: 5px;">
      <b>Group</b>: Data and Diagnostic
    </td>
  </tr>
  <tr>
    <td style="padding: 5px;">
      <b>Position</b>: Research engineer
      <br>
    </td>
  </tr>
  <tr>
    <td rowspan="4" style="width: 150px; text-align: center; vertical-align: middle;">
      <a href="https://github.com/RaulCapellanFernandez">
        <img src="https://media.licdn.com/dms/image/C4D03AQG3wdNNRHPqAQ/profile-displayphoto-shrink_400_400/0/1636441830003?e=1726704000&v=beta&t=9gCt_j8gI2z_XPGE0y8L2iVAAcUwdFV39lFtMD5nQUU" width="120" height="120" align="center"/>
      </a>
    </td>
    <td style="padding: 5px;">
      <strong style="font-size: 1em;">Daniela Lührsen</strong>
      <a href="https://www.linkedin.com/in/danielaluhrsen/" style="margin-left: 10px;">
        <img src="https://imgs.search.brave.com/SQsaFNKXL9x2pacICOrPpnY5c1-Eee1Vf0jOmntInaM/rs:fit:860:0:0:0/g:ce/aHR0cHM6Ly91cGxv/YWQud2lraW1lZGlh/Lm9yZy93aWtpcGVk/aWEvY29tbW9ucy9j/L2NhL0xpbmtlZElu/X2xvZ29faW5pdGlh/bHMucG5n" alt="LINKEDIN" width="16" height="16" align="center" />
      </a>
      <a href="https://orcid.org/0000-0003-3939-7343" style="margin-left: 10px;">
        <img src="https://orcid.org/sites/default/files/images/orcid_16x16.png" alt="ORCID" style="width: 16px; height: 16px;" />
      </a>
    </td>
  </tr>
  <tr>
    <td style="padding: 5px;">
      <b>Organization</b>: Barcelona Supercomputing Center
    </td>
  </tr>
  <tr>
    <td style="padding: 5px;">
      <b>Group</b>: Global Health Resilience
    </td>
  </tr>
  <tr>
    <td style="padding: 5px;">
      <b>Position</b>: Climate & Health Data Scientist
      <br>
    </td>
  </tr>
</table>


## Citation

- **APA Format:**
  - Lowe, R. (2020). *How to use the NetCDF files*. Package documentation. Retrieved from https://cran.r-project.org/).
